@@ -32,6 +32,7 @@
 (require 'cl-lib)
 (require 'subr-x)
 (require 'llama)
+(require 'el-job-ng)
 (require 'org-mem)
 (require 'org-mem-parser)
 
@@ -71,7 +72,11 @@ In that case, there may be nothing wrong with the known name."
 
 (defun org-mem-updater--handle-save (&optional file)
   "Arrange to scan entries and links in FILE, or current buffer file."
-  (unless file (setq file buffer-file-name))
+  (unless file
+    (if buffer-file-name
+        (setq file buffer-file-name)
+      (error "org-mem-updater--handle-save: Called with nil argument in %S"
+             (current-buffer))))
   (when (and (seq-find (##string-suffix-p % file) org-mem-suffixes)
              (not (backup-file-name-p file)))
     (org-mem-updater--scan-targeted file)))
@@ -84,15 +89,20 @@ In that case, there may be nothing wrong with the known name."
                      (seq-uniq)
                      (seq-filter (##cl-loop for xclude in org-mem-exclude
                                             never (string-search xclude %))))))
-    (el-job-launch :id 'org-mem-updater
-                   :inject-vars (append (org-mem--mk-work-vars) org-mem-inject-vars)
-                   :load-features (append '(org-mem-parser) org-mem-load-features)
+    (el-job-ng-run :inject-vars (append (org-mem--mk-work-vars) org-mem-inject-vars)
+                   :require (append '(org-mem-parser) org-mem-load-features)
                    :inputs truenames
                    :funcall-per-input #'org-mem-parser--parse-file
                    :callback #'org-mem-updater--finalize-targeted-scan)))
 
-(defun org-mem-updater--finalize-targeted-scan (parse-results _job)
+(defun org-mem-updater--finalize-targeted-scan (parse-results)
   "Handle PARSE-RESULTS from `org-mem-updater--scan-targeted'."
+  ;; Transitional #33
+  (let* ((ng-style-results parse-results)
+         (merged (pop ng-style-results)))
+    (while ng-style-results
+      (setq merged (org-mem--zip (pop ng-style-results) merged)))
+    (setq parse-results merged))
   (run-hook-with-args 'org-mem-pre-targeted-scan-functions parse-results)
   (seq-let (bad-paths file-data entries links problems) parse-results
     (org-mem-updater--forget-file-contents (append bad-paths (mapcar #'car file-data)))
@@ -350,8 +360,6 @@ Override this if you prefer different timer delays, or no timer."
     (advice-remove 'delete-file                    #'org-mem-updater--handle-delete)
     (cancel-timer org-mem-updater--timer)))
 
-(org-mem--def-whiny-alias 'org-mem-updater-ensure-entry-at-point-known   #'org-mem-updater-ensure-id-node-at-point-known "2025-05-21" "November")
-(org-mem--def-whiny-alias 'org-mem-updater--activate-timer   #'org-mem-updater--adjust-timer "2025-05-24" "November")
 (defvar org-mem-updater--id-or-ref-target<>old-links :obsolete)
 (defvar org-mem-updater--new-id-or-ref-targets :obsolete)
 
