@@ -19,9 +19,9 @@
 ;; URL:      https://github.com/meedstrom/org-mem
 ;; Created:  2025-03-15
 ;; Keywords: text
-;; Package-Version: 20251108.841
-;; Package-Revision: 0a33650ccb79
-;; Package-Requires: ((emacs "29.1") (el-job "2.5.1") (llama "0.5.0"))
+;; Package-Version: 20260123.656
+;; Package-Revision: 599b92afeb85
+;; Package-Requires: ((emacs "29.1") (el-job "2.6.1") (llama "0.5.0"))
 
 ;;; Commentary:
 
@@ -44,7 +44,7 @@
 (require 'cl-lib)
 (require 'subr-x)
 (require 'llama)
-(require 'el-job)
+(require 'el-job-ng)
 (require 'org-mem-parser)
 
 (defvar org-id-locations)
@@ -60,9 +60,8 @@
 (declare-function org-id-alist-to-hash "org-id")
 (declare-function org-id-hash-to-alist "org-id")
 (define-obsolete-variable-alias 'org-mem-watch-dirs-exclude 'org-mem-exclude "0.13.0 (May 2025)")
-(unless (and (boundp 'el-job-old-internal-version)
-             (>= el-job-old-internal-version 100))
-  (error "Update to el-job 2.5.1+ to use this version of org-mem"))
+(unless (fboundp 'el-job-ng-run)
+  (error "Update to el-job 2.6.1+ to use this version of org-mem"))
 
 (defgroup org-mem nil "Fast info from a large amount of Org file contents."
   :group 'org)
@@ -194,7 +193,7 @@ Quoted forms to eval in child process."
     ("^[ \t]*#\\+begin_src" . "^[ \t]*#\\+end_src")
     ("^[ \t]*#\\+begin_example" . "^[ \t]*#\\+end_example")
     ("^[ \t]*#\\+begin_comment" . "^[ \t]*#\\+end_comment")
-    ("^[ \t]*#\\+begin_transclude" . "^[ \t]*#\\+end_transclude"))
+    ("^[ \t]*#\\+transclude:" . "$"))
   "Alist of regular expressions matching boundaries of regions to avoid.
 These regions will not be scanned for links nor active timestamps."
   :type '(alist :key-type regexp :value-type regexp)
@@ -1232,7 +1231,7 @@ With TAKEOVER t, stop any already ongoing scan to start a new one.
 
 Argument MSG is an optional message to print.  If provided, it also
 overrides a default message printed when `org-mem-do-cache-text' is t."
-  (when (or takeover (not (el-job-is-busy 'org-mem)))
+  (when (or takeover (not (el-job-ng-busy-p 'org-mem)))
     (setq org-mem--time-at-begin-full-scan (current-time))
     (when msg
       (setq org-mem--reset-msg msg)
@@ -1240,10 +1239,9 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
       (redisplay t))
     (let ((files (org-mem--list-files-from-fs)))
       (when files
-        (el-job-launch :id 'org-mem
-                       :if-busy 'takeover
+        (el-job-ng-run :id 'org-mem
                        :inject-vars (append (org-mem--mk-work-vars) org-mem-inject-vars)
-                       :load-features (append '(org-mem-parser) org-mem-load-features)
+                       :require (append '(org-mem-parser) org-mem-load-features)
                        :eval org-mem-eval-forms
                        :inputs files
                        :funcall-per-input #'org-mem-parser--parse-file
@@ -1274,9 +1272,28 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
           (message nil)
           (redisplay))))))
 
+;; Transitional #33
+(defun org-mem--zip (list1 list2)
+  "Destructively zip two lists into one.
+Like the Dash expression \(-zip-with #\\='nconc list1 list2).
+
+LIST1 and LIST2 must be lists of identical length,
+and each element in them must be a list or nil."
+  (let (merged)
+    (while list1
+      (push (nconc (pop list1) (pop list2)) merged))
+    (when list2 (error "Lists differed in length"))
+    (nreverse merged)))
+
 (defvar org-mem--caused-retry nil)
-(defun org-mem--finalize-full-scan (parse-results _job)
+(defun org-mem--finalize-full-scan (parse-results)
   "Handle PARSE-RESULTS from `org-mem--scan-full'."
+  ;; Transitional #33
+  (let* ((ng-style-results parse-results)
+         (merged (pop ng-style-results)))
+    (while ng-style-results
+      (setq merged (org-mem--zip (pop ng-style-results) merged)))
+    (setq parse-results merged))
   (run-hook-with-args 'org-mem-pre-full-scan-functions parse-results)
   (mapc #'clrhash (hash-table-values org-mem--key<>subtable))
   (clrhash org-mem--title<>id)
@@ -1544,13 +1561,6 @@ If `org-mem-do-sync-with-org-id' t, also scrub `org-id-locations'."
                    (not (eq ?_ (aref other-dir (length (file-name-as-directory dir))))))
           (message "Option `org-mem-watch-dirs' has redundant subdirectories"))))))
 
-;; Benchmarks.  Try with (setq org-mem-watch-dirs nil) too!
-
-;; (clrhash org-mem--wild-filename<>truename)
-;; (benchmark-call #'org-mem--list-files-from-fs)  => 0.043 s
-;; (benchmark-call #'org-mem--list-files-from-fs)  => 0.004 s
-;; (benchmark-call #'org-roam-list-files)          => 4.145 s
-
 (defvar org-mem--dir<>bare-files (make-hash-table :test 'equal))
 (defvar org-mem--dedup-tbl (make-hash-table :test 'equal))
 (defun org-mem--list-files-from-fs ()
@@ -1690,8 +1700,8 @@ As an obsolete calling convention, MESSAGE can also be a symbol
 corresponding to your package name."
   (when (symbolp message)
     (setq message (format "%S waiting for org-mem..." message)))
-  (el-job-await 'org-mem-targeted n-secs message)
-  (el-job-await 'org-mem n-secs message))
+  (el-job-ng-await 'org-mem-targeted n-secs message)
+  (el-job-ng-await 'org-mem n-secs message))
 
 ;; REVIEW: Mixed feelings about including this tool, but it's the obvious tool
 ;; to use with `org-mem-entry-text' to generate backlink previews, for
@@ -1788,7 +1798,7 @@ org-id-locations:
       (org-mem--scan-full))))
 
 
-(defvar org-mem--bump-int 19 "Not a version number, but bumped sometimes.")
+(defvar org-mem--bump-int 20 "Not a version number, but bumped sometimes.")
 (defmacro org-mem--def-whiny-alias (old new when removed-by)
   "Define function OLD as effectively an alias for NEW.
 Also, calling OLD will emit a deprecation warning the first time.
@@ -1803,26 +1813,12 @@ may be removed from the package."
                 ,when ,removed-by ,new))
        (apply ,new args))))
 
-(org-mem--def-whiny-alias 'org-mem-link-dest                         #'org-mem-link-target                             "0.8.0 (2025-05-15)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-dest                              #'org-mem-target                                  "0.8.0 (2025-05-15)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-x-fontify-like-org                #'org-mem-fontify-like-org                        "0.10.0 (2025-05-18)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-block                             #'org-mem-await                                   "0.12.0 (2025-05-22)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem--abbr-truename                    #'org-mem--truename-maybe                         "0.12.0 (2025-05-22)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-entry-olpath-with-title           #'org-mem-entry-olpath-with-file-title            "0.13.1 (2025-05-28)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-entry-olpath-with-title-with-self #'org-mem-entry-olpath-with-self-with-file-title  "0.13.1 (2025-05-28)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-entry-olpath-with-self-with-title #'org-mem-entry-olpath-with-self-with-file-title  "0.13.1 (2025-05-28)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-olpath-with-title                 #'org-mem-olpath-with-file-title                  "0.13.1 (2025-05-28)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-olpath-with-title-with-self       #'org-mem-olpath-with-self-with-file-title        "0.13.1 (2025-05-28)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-olpath-with-self-with-title       #'org-mem-olpath-with-self-with-file-title        "0.13.1 (2025-05-28)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-file-mtime-int                    #'org-mem-file-mtime-floor                        "0.14.0 (2025-05-30)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-entries-with-active-timestamps    #'org-mem-all-entries-with-active-timestamps      "0.14.0 (2025-05-30)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-files-with-active-timestamps      #'org-mem-all-files-with-active-timestamps        "0.14.0 (2025-05-30)" "2025-11-30")
-(org-mem--def-whiny-alias 'org-mem-heading-lvl                       #'org-mem-level                                   "0.21.0 (2025-09-30)" "2026-01-30")
 (defvar org-mem--file<>metadata :renamed)
 (defvar org-mem--file<>entries  :renamed)
 
-(define-obsolete-function-alias 'org-mem-entry-olpath-with-file-title-with-self #'org-mem-entry-olpath-with-self-with-file-title  "0.22.0 (2025-10-01)")
-(define-obsolete-function-alias 'org-mem-olpath-with-file-title-with-self       #'org-mem-olpath-with-self-with-file-title        "0.22.0 (2025-10-01)")
+(org-mem--def-whiny-alias 'org-mem-entry-olpath-with-file-title-with-self #'org-mem-entry-olpath-with-self-with-file-title  "0.22.0 (2025-10-01)" "2026-04-30")
+(org-mem--def-whiny-alias 'org-mem-olpath-with-file-title-with-self       #'org-mem-olpath-with-self-with-file-title        "0.22.0 (2025-10-01)" "2026-04-30")
+
 (defvar org-mem-forget-link-functions :obsolete) ;; 2025-10-15 but unused for long already
 
 (provide 'org-mem)
